Range-v3: ranges::v3::action::split_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Synopsis of methods | Public Member Functions | List of all members
ranges::v3::action::split_fn Struct Reference

## Synopsis of methods
constexpr action< split_fn > | split {}

## Public Member Functions
template<typename Rng , typename Fun , requires = (view::split_fn::FunctionConcept<Rng, Fun>())>
std::vector< split_value_t< Rng > > | operator() (Rng &&rng, Fun fun) const
template<typename Rng , typename Fun , requires = (view::split_fn::PredicateConcept<Rng, Fun>())>
std::vector< split_value_t< Rng > > | operator() (Rng &&rng, Fun fun) const
template<typename Rng , requires = (view::split_fn::ElementConcept<Rng>())>
std::vector< split_value_t< Rng > > | operator() (Rng &&rng, range_value_type_t< Rng > val) const
template<typename Rng , typename Sub , requires = (view::split_fn::SubRangeConcept<Rng, Sub>())>
std::vector< split_value_t< Rng > > | operator() (Rng &&rng, Sub &&sub) const